exceptiontools.TempoError
=========================

.. inheritance-diagram:: abjad.tools.exceptiontools.TempoError.TempoError
   :private-bases:

.. autoclass:: abjad.tools.exceptiontools.TempoError.TempoError

Special Methods
---------------

.. automethod:: abjad.tools.exceptiontools.TempoError.TempoError.__delattr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.TempoError.TempoError.__getitem__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.TempoError.TempoError.__getslice__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.TempoError.TempoError.__repr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.TempoError.TempoError.__setattr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.TempoError.TempoError.__setstate__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.TempoError.TempoError.__str__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.TempoError.TempoError.__unicode__

    Inherited from :py:class:`exceptions.BaseException`
